# AquaKit

Refractive multi-camera geometry foundation for the Aqua ecosystem.

::::{grid} 1 2 2 3
:gutter: 3

:::{grid-item-card} API Reference
:link: api/index
:link-type: doc

Module-by-module API documentation with type signatures and examples.
:::

:::{grid-item-card} Contributing
:link: contributing
:link-type: doc

Development setup, coding standards, and contribution workflow.
:::

::::

```{toctree}
:maxdepth: 2
:hidden:

api/index
contributing
```
